/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterContentInit, ElementRef, EventEmitter, OnDestroy, Renderer2, ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { NgControl } from '@angular/forms';
import { FloatingLabelPosition } from './models/label-position';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI FloatingLabel component for Angular]({% slug overview_floatinglabel %}).
 * Provides floating labels to `input` elements.
 *
 * The FloatingLabel supports both Template and Reactive Forms and
 * [can contain Kendo UI for Angular Input components such as `kendo-combobox` and `kendo-numerictextbox`,
 * or `kendo-textbox`](slug:associate_floatinglabel).
 *
 * @example
 * ```html
 *     <kendo-floatinglabel text="First name">
 *       <kendo-textbox [(ngModel)]="name"></kendo-textbox>
 *     </kendo-floatinglabel>
 * ```
 */
export declare class FloatingLabelComponent implements AfterContentInit, OnDestroy {
    private elementRef;
    private renderer;
    private changeDetectorRef;
    private localization;
    /**
     * Represents the current floating label position.
     */
    get labelPosition(): FloatingLabelPosition;
    hostClasses: boolean;
    get focusedClass(): boolean;
    get invalidClass(): boolean;
    /**
     * @hidden
     */
    direction: string;
    /**
     * Sets the CSS Styles that will be rendered on the actual label element.
     * Supports the type of values that are supported by [ngStyle](link:site.data.urls.angular['ngstyleapi']) directive.
     */
    labelCssStyle: any;
    /**
     * Sets the CSS Classes that will be rendered on the actual label element.
     * Supports the type of values that are supported by [ngClass](link:site.data.urls.angular['ngclassapi']) directive.
     */
    labelCssClass: any;
    /**
     * Sets the `id` attribute of the input inside the floating label.
     */
    id: string;
    /**
     * Specifies the text content of the floating label which describes the input.
     */
    text: string;
    /**
     * Allows marking a form field as optional. By default renders the `Optional` text when enabled.
     * The text can be customized by providing a custom message ([see example]({% slug label_globalization %}#toc-custom-messages)).
     *
     * The default value is `false`
     */
    optional: boolean;
    /**
     * Fires after the floating label position is changed.
     */
    positionChange: EventEmitter<FloatingLabelPosition>;
    kendoInput: any;
    formControl: NgControl;
    /**
     * @hidden
     */
    focused: boolean;
    /**
     * @hidden
     */
    empty: boolean;
    /**
     * @hidden
     */
    invalid: boolean;
    /**
     * @hidden
     */
    labelId: string;
    private subscription;
    private autoFillStarted;
    constructor(elementRef: ElementRef, renderer: Renderer2, changeDetectorRef: ChangeDetectorRef, localization: LocalizationService);
    /**
     * @hidden
     */
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    textFor(key: string): string;
    private subscribe;
    private updateState;
    private setAriaLabelledby;
    private setLabelFor;
    private handleAutofill;
    private addHandlers;
    private validateSetup;
    static ɵfac: i0.ɵɵFactoryDeclaration<FloatingLabelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FloatingLabelComponent, "kendo-floatinglabel", ["kendoFloatingLabel"], { "labelCssStyle": { "alias": "labelCssStyle"; "required": false; }; "labelCssClass": { "alias": "labelCssClass"; "required": false; }; "id": { "alias": "id"; "required": false; }; "text": { "alias": "text"; "required": false; }; "optional": { "alias": "optional"; "required": false; }; }, { "positionChange": "positionChange"; }, ["kendoInput", "formControl"], ["*"], true, never>;
}
