/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2, NgZone } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Label directive for Angular]({% slug overview_label %}).
 * The Label associates a focusable Angular component or an HTML element
 * with a `label` tag by using the `[for]` property binding.
 *
 * To associate a component by using the `label` element, either:
 * * Set the `[for]` property binding to a
 * [template reference variable](link:site.data.urls.angular['templatesyntax']#template-reference-variables--var-), or
 * * Set the `[for]` property binding to an `id` HTML string value.
 *
 * @example
 * ```ts
 * _@Component({
 * selector: 'my-app',
 * template: `
 *  <div class="row example-wrapper" style="min-height: 450px;">
 *    <div class="col-xs-12 col-md-6 example-col">
 *      <label [for]="datepicker">DatePicker: </label>
 *      <kendo-datepicker #datepicker></kendo-datepicker>
 *    </div>
 *
 *    <div class="col-xs-12 col-md-6 example-col">
 *      <label for="input">Input: </label>
 *      <input id="input" />
 *    </div>
 *  </div>
 * `
 * })
 * class AppComponent { }
 * ```
 */
export declare class LabelDirective {
    private label;
    private renderer;
    private zone;
    /**
     * Sets the focusable target to either of the following options ([see example]({% slug overview_label %})):
     * * A [template reference variable](link:site.data.urls.angular['templatesyntax']#template-reference-variables--var-), or
     * * An `id` HTML string value.
     */
    for: string | {
        focus: Function;
    };
    get labelFor(): string;
    /**
     * @hidden
     *
     * Allows the user to specify if the label CSS class should be rendered or not.
     */
    labelClass: boolean;
    private clickListener;
    constructor(label: ElementRef<HTMLLabelElement>, renderer: Renderer2, zone: NgZone);
    /**
     * @hidden
     */
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    setAriaLabelledby(): void;
    private getFocusableComponent;
    private handleClick;
    static ɵfac: i0.ɵɵFactoryDeclaration<LabelDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<LabelDirective, "label[for]", never, { "for": { "alias": "for"; "required": false; }; "labelClass": { "alias": "labelClass"; "required": false; }; }, {}, never, never, true, never>;
}
